.. _prediction_algorithms_package:

prediction_algorithms package
=============================

.. automodule:: surprise.prediction_algorithms

You may want to check the :ref:`notation standards <notation_standards>`
before diving into the formulas.


.. toctree::
   :includehidden:

   algobase
   predictions_module
   basic_algorithms
   knn_inspired
   matrix_factorization
   slope_one
   co_clustering
